//********************************************************************************
// Name:Counter.cpp
// Author: Smacq
// Copyright: Smacq
// Date: 27-11-2024
// Brief:
// The Counter functions of 1252A_DAQ, get 10s Ct0-3 signal cycle value and print it.
// You can loot out user manual know more about functions or Device info.
// 1252A_DAQ only connect USB execution result:
// 0
// 0
// 0
// 0
// 0
// 0
// 0 second:
// Ct_channel: 0 Ct_counter: 1
// Ct_channel: 1 Ct_counter: 1
// Ct_channel: 2 Ct_counter: 1
// Ct_channel: 3 Ct_counter: 1
// ...
// 9 second:
// Ct_channel: 0 Ct_counter: 1
// Ct_channel: 1 Ct_counter: 1
// Ct_channel: 2 Ct_counter: 1
// Ct_channel: 3 Ct_counter: 1
// 0
// 0
// 0
// 0

// Error code:
// Execution successful  =  0
// Device not found      = -1
// DevIndex overflow     = -2
// Device firmware error = -3
// Device closed         = -4
// Transfer data error   = -5
// PC Out of memory      = -6
// Execution timeout     = -7
// Reading thread not on = -8
//********************************************************************************

#include <QCoreApplication>
extern "C"{
#include "usb-1000.h"
}
#include <QDebug>
#include <windows.h>
#include <stdio.h>


int main(void)
{
    int Dev_Index = 0;
    int ct_count, error_code;
    double ct_time;
    byte CtrNum = 15;
    byte CtrMode = 0;
    byte CtrEdge = 1;

    error_code = OpenDevice(Dev_Index); // Turn on the specified device.
    printf("%d\n", error_code);
    error_code = ResetDevice(Dev_Index); // Reset the specified device.
    printf("%d\n", error_code);
    error_code = StartRead(Dev_Index); // Turn on Device reading thread
    printf("%d\n", error_code);
    error_code = TransDioIn(Dev_Index, 1); // Turn on Device Digital IO Transfer thread
    printf("%d\n", error_code);
    /*
     * Set Device Counter: Device_0, CrtNum_Ct0-3, CrtMode_1(cycle)
     * CtrNum:1=0x1=4-bit(0001) Ct3~1 is CLOSE and Ct0 is OPEN.15=0xF=4-bit(1111) Ct3~0 is OPEN.
     * CtrMode:0=edge or 1=cycle or 2=positive pulse width or 3=negative pulse width 1252A only support param 0~3
     * CtrEdge:1=rising or 2=falling 1252A only support param 1/2
     */
    error_code = SetCounter(Dev_Index, CtrNum, CtrMode, CtrEdge);
    printf("%d\n", error_code);
    error_code = StartCounter(Dev_Index, CtrNum, 1); // Start Device Counter record
    printf("%d\n", error_code);

    // Run 10s for catch Ct0~3 signal, each second update input signal value and print
    for (int i = 0; i < 10; i++)
    {
        Sleep(1000); // delay 1s
        printf("%d second:\n", i);
        // Get Ct0~3 signal cycle value and print
        for (byte ct_channel = 0; ct_channel < 4; ct_channel++)
        {
            // GetCounter() only support CrtMode=0(edge), return edge count
            if (CtrMode == 0)
            {
                ct_count = GetCounter(Dev_Index, ct_channel);
                printf("Ct_channel:%d Ct_count:%d\n", ct_channel, ct_count);
            }
            // GetCtrTime() not support CrtMode=0(edge), return value is time unit us
            else
            {
                ct_time = GetCtrTime(Dev_Index, ct_channel);
                printf("Ct_channel:%d Ct_time:%f\n", ct_channel, ct_time);
            }
        }
    }
    error_code = StartCounter(Dev_Index, CtrNum, 0); // Stop Device Counter record
    printf("%d\n", error_code);
    error_code = ClearCounter(Dev_Index, CtrNum); // Clear Ct0-3 count value
    printf("%d\n", error_code);
    error_code = TransDioIn(Dev_Index, 0); // Turn off Device Digital IO transfer thread
    printf("%d\n", error_code);
    error_code = StopRead(Dev_Index); // Turn off Device reading thread
    printf("%d\n", error_code);
    CloseDevice(Dev_Index); // Close Device

    scanf("Delay for show result");
}
