//********************************************************************************
// Name:ai continuous.cpp
// Author: Smacq
// Copyright: Smacq
// Date: 26-11-2024
// Brief:
// The Ai functions of 1252A_DAQ, continuous acquisition.
// Acquisition Ai0 channel 100 data point of 10 times.
// You can loot out user manual know more about functions or Device info.

// 1252A_DAQ only connect USB execution result:
// 0
// 0
// 0
// 0
// 0
// 0
// 0
// 0
// Start acquisition times:0 Ai_data_array[0-99]:
// FIFO buffer value:1999995
// Ai_data_array[0]:-3.481503
// Ai_data_array[1]:-3.481503
// ...
// Ai_data_array[99]:-3.476113
// Start acquisition times:1 Ai_data_array[0-99]:
// FIFO buffer value:1999989
// Ai_data_array[0]:-3.478808
// ...
// Start acquisition times:9 Ai_data_array[0-99]:
// ...
// Ai_data_array[99]:-3.476113
// 0
// 0

// Error code:
// Execution successful  =  0
// Device not found      = -1
// DevIndex overflow     = -2
// Device firmware error = -3
// Device closed         = -4
// Transfer data error   = -5
// PC Out of memory      = -6
// Execution timeout     = -7
// Reading thread not on = -8
//********************************************************************************

#include <QCoreApplication>
extern "C"{
#include "usb-1000.h"
}
#include <QDebug>
#include <stdio.h>

int main(void)
{
    int Dev_Index = 0; // Device index defull is 0
    int error_code, buffer;
    float Ai_data_array[1600];

    error_code = OpenDevice(Dev_Index); // Turn on the specified device.
    printf("%d\n", error_code);
    error_code = ResetDevice(Dev_Index); // Reset the specified device.
    printf("%d\n", error_code);
    error_code = SetUSB1AiRange(Dev_Index, 5); // Set Device Ai input voltage range 5 = -5~5V or 10 = 0~10V
    printf("%d\n", error_code);
    error_code = SetSampleRate(Dev_Index, 1000); // Set Ai Sampling rate 1kS/s
    printf("%d\n", error_code);
    error_code = SetChanMode(Dev_Index, 1); // Set Device Ai input channel mode 0=diff or 1=NRSE or 3=RSE
    printf("%d\n", error_code);
    /*
     * Set Device Ai0 channel open
     * 1=0x0001=16-bit(0000 0000 0000 0001) Ai15~1 is CLOSE and Ai0 is OPEN.
     * 3=0x0003=16-bit(0000 0000 0000 0011) Ai15~2 is CLOSE and Ai1~0 is OPEN.
     * 65535=0xFFFF=16-bit(1111 1111 1111 1111) Ai15~0 is OPEN.
     */
    error_code = SetChanSel(Dev_Index, 1);
    printf("%d\n", error_code);
    error_code = StartRead(Dev_Index); // Turn on Device reading thread
    printf("%d\n", error_code);
    error_code = SetSoftTrig(Dev_Index, 1); // Turn on Device software trigger
    printf("%d\n", error_code);

    // Continuous acquisition 10 times
    for (int i = 0; i < 10; i++)
    {
        /*
         * Ai_FIFO_buffer range 0~200000
         * GetAiChans() return the remaining Device FIFO buffer value,
         * FIFO buffer 100 data points start save to Ai_data_array_ptr is Ai_data_array[0:100]
         * Num: Each opened Ai channel will get this amount of data.
         * Suggest setting this value within sampling rate 10-20 %.
         * Timeout time unit ms, Suggest timeout>(Num*Channel_count/samplerate)*1000.
         * Avoid GetAiChans() func timeout return -7.
         */
        buffer = GetAiChans(Dev_Index, 100, 1, Ai_data_array, 200);
        printf("FIFO buffer value:%d\n", buffer);

        // Print Ai_data_array to Console
        printf("Start acquisition times:%d Ai_data_array[0-99]:\n", i);
        for (int j = 0; j < 100; j++)
            printf("Ai_data_array[%d]:%f\n", j, Ai_data_array[j]);

        // Add your code here handle data
    }

    error_code = SetSoftTrig(Dev_Index, 0); // Turn off Device software trigger
    printf("%d\n", error_code);
    error_code = StopRead(Dev_Index); // Turn off Device reading thread
    printf("%d\n", error_code);
    CloseDevice(Dev_Index); // Close Device

    scanf("Delay for show result");
}

