//**********************************************************************
// @Name: Digital io.cpp
// @Author: Smacq
// @Copyright: Smacq
// @Date: 27-11-2024
// @Brief: The digital I/O functions of 1252A_DAQ, set Do output HIGH/LOW and read Di input value.
// Digital voltage range:
// Do Pin HIGH is 3.3V and LOW is 0V, Di Pin HIGH is 3.3-5V and LOW is 0-1.2V.
// You can loot out user manual know more about functions or Device info.
//
// 1252A_DAQ only connect USB execution result:
// 0
// 0
// 0
// 0
// 0
// Now Do15-0 is all HIGH
// 0
// Now Do15-0 is all LOW
// 0
// Now Do15-0 is all HIGH
// 0
// Now Do15-0 is all LOW
// 0
// Now Do15-0 is all HIGH
// 0
// Now Do15-0 is all LOW
// 0
// Now DO 0 is HIGH, other DO is LOW. SetDioOut value is 1
// ...
// Now DO 15 is HIGH, other DO is LOW. SetDioOut value is 32768
// 0 second: Di_value: 65535
// ...
// 9 second: Di_value: 65535
// 0
// 0
//
// Error code:
// Execution successful  =  0
// Device not found      = -1
// DevIndex overflow     = -2
// Device firmware error = -3
// Device closed         = -4
// Transfer data error   = -5
// PC Out of memory      = -6
// Execution timeout     = -7
// Reading thread not on = -8
//**********************************************************************

#include <QCoreApplication>
extern "C"{
#include "usb-1000.h"
}
#include <QDebug>
#include<windows.h>
#include<stdio.h>

int main(void)
{
   int Dev_Index = 0;
   int error_code;
   int Do_value, Di_value;

   error_code = OpenDevice(Dev_Index); // Open Device, return value assignment and print error_code.
   printf("%d\n", error_code);
   error_code = ResetDevice(Dev_Index); // Reset and init Device
   printf("%d\n", error_code);
   error_code = StartRead(Dev_Index); // Turn on Device reading thread
   printf("%d\n", error_code);
   error_code = TransDioIn(Dev_Index, 1); // Turn on Device Digital IO Transfer thread
   printf("%d\n", error_code);

   // Set All Do Pin output HIGH and then LOW, interval of 1 second.
   for (int i = 0; i < 3; i++)
   {
      // Set Do Pin output, 65535=0xFFFF=16-bit(1111 1111 1111 1111) Do15-0 all HIGH.
      error_code = SetDioOut(Dev_Index, 65535);
      printf("%d\n", error_code);
      if (error_code == 0)
         printf("Now Do15-0 is all HIGH\n");
      Sleep(1000);
      // Set Do Pin output, 0=0x0000=16-bit(0000 0000 0000 0000) Do15-0 all LOW.
      error_code = SetDioOut(Dev_Index, 0);
      printf("%d\n", error_code);
      if (error_code == 0)
         printf("Now Do15-0 is all LOW\n");
      Sleep(1000);
   }
   // Set single DO_Pin output HIGH, from Do0 to Do15 other Do PIN is LOW.
   for (int DO_bit = 0; DO_bit < 16; DO_bit++)
   {
      // 1=0x0001=16-bit(0000 0000 0000 0001) Do15-1 is LOW and Do0 is HIGH, and the like.
      Do_value = 1 << DO_bit;
      error_code = SetDioOut(Dev_Index, Do_value);
      printf("%d\n", error_code);
      if (error_code == 0)
         printf("Now DO %d is HIGH, other DO is LOW. SetDioOut value is %d\n", DO_bit, Do_value);
      Sleep(1000);
   }
   // Get Di Pin input value in 10s, update time is 1s (When Di Pin is FLOATING default HIGH).
   for (int second = 0; second < 10; second++)
   {
      // Di_value is 65535=0xFFFF=16-bit(1111 1111 1111 1111) Di15-0 input Pin value all HIGH.
      Di_value = GetDioIn(Dev_Index);
      printf("%d second: Di_value:%d\n", second, Di_value);
      Sleep(1000);
   }

   error_code = TransDioIn(Dev_Index, 0); // Turn off Device Digital IO transfer thread
   printf("%d\n", error_code);
   error_code = StopRead(Dev_Index); // Turn off Device reading thread
   printf("%d\n", error_code);
   CloseDevice(Dev_Index); // Close Device

   scanf("Delay for show result");
}
